From 5a22c6bbfc436358fa13d9c32b6b3bdba3dbb9ea Mon Sep 17 00:00:00 2001
From: Abhishek Singh <abhishekkumarsingh.cse@gmail.com>
Date: Tue, 16 Apr 2013 19:17:16 +0530
Subject: [PATCH 2/2] Fix segmentation fault in test_io.

tests_set_cwd is used and relativepath calculation method is changed and is made general based on
basedir.
---
 Makefile.am                |  3 ++-
 src/tests/cmocka/test_io.c | 21 +++++++++++++++++----
 2 files changed, 19 insertions(+), 5 deletions(-)

diff --git a/Makefile.am b/Makefile.am
index 332669551a781263e44fd855a920d370b5898c15..27bb8d3cb1e28f63e63c8b8c061d42a41a8b38ec 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1241,7 +1241,8 @@ test_find_uid_LDADD = \
 
 test_io_SOURCES = \
     src/tests/cmocka/test_io.c \
-    src/util/io.c
+    src/util/io.c \
+    src/tests/common.c
 test_io_CFLAGS = \
     $(AM_CFLAGS)
 test_io_LDADD = \
diff --git a/src/tests/cmocka/test_io.c b/src/tests/cmocka/test_io.c
index 4d21b2e25d3f35cc155b6410bcb4ce8963a59c15..047173428a518c09a5875b032b9014f762617670 100644
--- a/src/tests/cmocka/test_io.c
+++ b/src/tests/cmocka/test_io.c
@@ -24,6 +24,7 @@
 
 #include <stdio.h>
 #include <fcntl.h>
+#include <errno.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
@@ -32,10 +33,12 @@
 #include <cmocka.h>
 #include <dirent.h>
 #include <unistd.h>
+#include <libgen.h>
 
 #include "limits.h"
 #include "util/io.h"
 #include "util/util.h"
+#include "tests/common.h"
 
 #define FILE_PATH TEST_DIR"/test_io.XXXXXX"
 #define NON_EX_PATH "non-existent-path"
@@ -49,8 +52,11 @@ static char *get_filepath(char path[])
     ret = mkstemp(path);
 
     if (ret == -1) {
-        fprintf(stderr, "mkstemp failed\n");
+        int err = errno;
+        fprintf(stderr, "mkstemp failed with path:'%s' [%s]\n",
+                path, strerror(err));
     }
+    assert_false(ret == -1);
 
     return path;
 }
@@ -58,9 +64,13 @@ static char *get_filepath(char path[])
 void setup_dirp(void **state)
 {
     DIR *dirp = opendir(TEST_DIR);
-    if (dirp != NULL){
-        *state = (void *)dirp;
+    if (dirp == NULL) {
+        int err = errno;
+        fprintf(stderr, "Could not open directory:'%s' [%s]\n",
+                TEST_DIR, strerror(err));
     }
+    assert_non_null(dirp);
+    *state = (void *)dirp;
 }
 
 void teardown_dirp(void **state)
@@ -111,10 +121,12 @@ void test_sss_openat_cloexec_success(void **state)
     int dir_fd;
     int flags = O_RDWR;
     char path[PATH_MAX] = {'\0'};
+    char *basec;
     const char *relativepath;
 
-    relativepath = strchr(get_filepath(path), 't');
     dir_fd = dirfd((DIR *)*state);
+    basec = strdup(get_filepath(path));
+    relativepath = basename(basec);
     fd = sss_openat_cloexec(dir_fd, relativepath, flags, &ret);
     assert_true(fd != -1);
 
@@ -153,5 +165,6 @@ int main(void)
                                  teardown_dirp)
     };
 
+    tests_set_cwd();
     return run_tests(tests);
 }
-- 
1.8.1.4

